@@ -970,14 +970,14 @@ class GoogleCloudDatastoreSessionInterface(SessionInterface):
 class GoogleFireStoreSessionInterface(SessionInterface):
     """A Session interface that uses GCP firestore as backend"""
 
-    from google.cloud import firestore_v1 as firestore
-
     serializer = pickle
     session_class = GoogleFireStoreSession
 
     def __init__(
         self, client, collection, key_prefix, use_signer=False, permanent=True
     ):
+        # pylint: disable=W0611
+        from google.cloud import firestore_v1 as firestore  # noqa: F401
 
         if client is None:
             raise Exception("Please set Firestore Client")
@@ -989,21 +989,17 @@ class GoogleFireStoreSessionInterface(SessionInterface):
         self.permanent = permanent
         self.has_same_site_capability = hasattr(self, "get_cookie_samesite")
 
-    @firestore.transactional
-    def _fs_get_doc(self, transaction, doc_ref):
-        doc = doc_ref.get(transaction=transaction)
-        if doc.exists:
-            return doc.to_dict()
-        return None
-
-    @firestore.transactional
-    def _fs_set_doc(self, transaction, doc_ref, doc_data):
-        transaction.set(doc_ref, doc_data)
-
     def _fs_delete_doc(self, doc_ref):
         doc_ref.delete()
 
     def open_session(self, app, request):
+        @firestore.transactional
+        def _fs_get_doc(transaction, doc_ref):
+            doc = doc_ref.get(transaction=transaction)
+            if doc.exists:
+                return doc.to_dict()
+            return None
+
         sid = request.cookies.get(app.config["SESSION_COOKIE_NAME"])
         if not sid:
             sid = self._generate_sid()
@@ -1022,7 +1018,7 @@ class GoogleFireStoreSessionInterface(SessionInterface):
         store_id = self.key_prefix + sid
         document_ref = self.store.document(document_id=store_id)
         transaction = self.client.transaction()
-        document = self._fs_get_doc(transaction, document_ref)
+        document = _fs_get_doc(transaction, document_ref)
 
         if document and document["expiration"] <= datetime.utcnow().replace(
             tzinfo=pytz.UTC
@@ -1040,6 +1036,10 @@ class GoogleFireStoreSessionInterface(SessionInterface):
         return self.session_class(sid=sid, permanent=self.permanent)
 
     def save_session(self, app, session, response):
+        @firestore.transactional
+        def _fs_set_doc(transaction, doc_ref, doc_data):
+            transaction.set(doc_ref, doc_data)
+
         domain = self.get_cookie_domain(app)
         path = self.get_cookie_path(app)
         store_id = self.key_prefix + session.sid
@@ -1064,7 +1064,7 @@ class GoogleFireStoreSessionInterface(SessionInterface):
         transaction = self.client.transaction()
 
         s_data = {"id": store_id, "val": value, "expiration": expires}
-        self._fs_set_doc(transaction, document_ref, s_data)
+        _fs_set_doc(transaction, document_ref, s_data)
 
         if self.use_signer:
             session_id = self._get_signer(app).sign(want_bytes(session.sid))
